==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/policy_analysis_client/models/QosClassMapStatistics.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class QosClassMapStatistics(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'classMapName': 'str',


            'dropRate': 'int',


            'numBytes': 'int',


            'numPackets': 'int',


            'offeredRate': 'int',


            'queueBandwidthbps': 'str',


            'queueDepth': 'int',


            'queueNoBufferDrops': 'int',


            'queueTotalDrops': 'int',


            'refreshedAt': 'int'

        }

        self.attributeMap = {

            'classMapName': 'classMapName',

            'dropRate': 'dropRate',

            'numBytes': 'numBytes',

            'numPackets': 'numPackets',

            'offeredRate': 'offeredRate',

            'queueBandwidthbps': 'queueBandwidthbps',

            'queueDepth': 'queueDepth',

            'queueNoBufferDrops': 'queueNoBufferDrops',

            'queueTotalDrops': 'queueTotalDrops',

            'refreshedAt': 'refreshedAt'

        }



        self.classMapName = None # str


        self.dropRate = None # int


        self.numBytes = None # int


        self.numPackets = None # int


        self.offeredRate = None # int


        self.queueBandwidthbps = None # str


        self.queueDepth = None # int


        self.queueNoBufferDrops = None # int


        self.queueTotalDrops = None # int


        self.refreshedAt = None # int

==> uniq-1.4.0.36-py3-none-any.whl: uniq/apis/nb/clients/policy_analysis_client/models/QosClassMapStatistics.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class QosClassMapStatistics(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'queueNoBufferDrops': 'int',
            
            
            'refreshedAt': 'int',
            
            
            'queueTotalDrops': 'int',
            
            
            'classMapName': 'str',
            
            
            'dropRate': 'int',
            
            
            'numBytes': 'int',
            
            
            'numPackets': 'int',
            
            
            'queueBandwidthbps': 'str',
            
            
            'queueDepth': 'int',
            
            
            'offeredRate': 'int'
            
        }

        self.attributeMap = {
            
            'queueNoBufferDrops': 'queueNoBufferDrops',
            
            'refreshedAt': 'refreshedAt',
            
            'queueTotalDrops': 'queueTotalDrops',
            
            'classMapName': 'classMapName',
            
            'dropRate': 'dropRate',
            
            'numBytes': 'numBytes',
            
            'numPackets': 'numPackets',
            
            'queueBandwidthbps': 'queueBandwidthbps',
            
            'queueDepth': 'queueDepth',
            
            'offeredRate': 'offeredRate'
            
        }       

        
        
        self.queueNoBufferDrops = None # int
        
        
        self.refreshedAt = None # int
        
        
        self.queueTotalDrops = None # int
        
        
        self.classMapName = None # str
        
        
        self.dropRate = None # int
        
        
        self.numBytes = None # int
        
        
        self.numPackets = None # int
        
        
        self.queueBandwidthbps = None # str
        
        
        self.queueDepth = None # int
        
        
        self.offeredRate = None # int
